@@ -221,7 +221,9 @@ def MergePanelView(columns, dtypes, action_: action.ActionMerge, on_merge_action
         if action_.var_name_other:
             v.Switch(v_model=action_.on_index, on_v_model=lambda v: on_merge_action(replace(action_, on_index=v)), label="Join on index")
             if not action_.on_index:
-                with v.BtnToggle(v_model=how_options.index(action_.how), on_v_model=lambda v: on_merge_action(replace(action_, how=how_options[v]))):
+                with v.BtnToggle(
+                    v_model=how_options.index(action_.how), on_v_model=lambda v: on_merge_action(replace(action_, how=how_options[v])), mandatory=True
+                ):
                     with Tooltip("Inner (default)"):
                         sol.Button(icon_name="mdi-set-center")
                     with Tooltip("Left outer"):
