@@ -51,7 +51,7 @@ def TransformPanel(state, dispatch, on_reset, on_save, breakpoints, assistant_mo
             dispatch((actions_store.e_insert_index, index))
 
     add_state, set_add_state = reacton.use_state(
-        cast(Union[action.ActionFilter, action.ActionSelectColumns, action.ActionDropColumns, action.ActionGroupBy], action.ActionFilter())
+        cast(Union[action.ActionFilter, action.ActionSelectColumns, action.ActionDropColumns, action.ActionGroupBy, action.ActionMerge], action.ActionFilter())
     )
     dialog_state, set_dialog_state = reacton.use_state(cast(action.Action, action.ActionFilter()))
 
